==> haskell-dlist-0.8.0.4-1-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-dlist.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: dlist
version: 0.8.0.4
id: dlist-0.8.0.4-8Td44GecKNEJmy7QK3HIQc
key: dlist-0.8.0.4-8Td44GecKNEJmy7QK3HIQc
license: BSD3
copyright: 2006-2009 Don Stewart, 2013-2016 Sean Leather
maintainer: Sean Leather <sean.leather@gmail.com>
homepage: https://github.com/spl/dlist
synopsis: Difference lists
description:
    Difference lists are a list-like type supporting O(1) append. This is
    particularly useful for efficient logging and pretty printing (e.g. with the
    Writer monad), where list append quickly becomes too expensive.
category: Data
author: Don Stewart
exposed: True
indefinite: False
exposed-modules:
    Data.DList
abi: 891025a77d043cfd28f763ce7f5a4b16
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/dlist-0.8.0.4
library-dirs: /usr/lib/ghc-8.2.2/site-local/dlist-0.8.0.4
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/dlist-0.8.0.4
hs-libraries: HSdlist-0.8.0.4-8Td44GecKNEJmy7QK3HIQc
depends:
    base-4.10.1.0 deepseq-1.4.3.0
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             deepseq-1.4.3.0=e843b5d736cc095915bf2399fddf152e
haddock-interfaces: /usr/share/doc/haskell-dlist/html/dlist.haddock
haddock-html: /usr/share/doc/haskell-dlist/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-dlist-0.8.0.4-5-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-dlist.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: dlist
version: 0.8.0.4
id: dlist-0.8.0.4-CrGJIvQnsM82JxkEwejrYD
key: dlist-0.8.0.4-CrGJIvQnsM82JxkEwejrYD
license: BSD-3-Clause
copyright: 2006-2009 Don Stewart, 2013-2016 Sean Leather
maintainer: Sean Leather <sean.leather@gmail.com>
author: Don Stewart
homepage: https://github.com/spl/dlist
synopsis: Difference lists
description:
    Difference lists are a list-like type supporting O(1) append. This is
    particularly useful for efficient logging and pretty printing (e.g. with the
    Writer monad), where list append quickly becomes too expensive.
category: Data
abi: f79b3ead594e04b4f22b6b2afc0a8656
exposed: True
exposed-modules:
    Data.DList
import-dirs: /usr/lib/ghc-8.4.3/site-local/dlist-0.8.0.4
library-dirs: /usr/lib/ghc-8.4.3/site-local/dlist-0.8.0.4
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/dlist-0.8.0.4
hs-libraries: HSdlist-0.8.0.4-CrGJIvQnsM82JxkEwejrYD
depends:
    base-4.11.1.0 deepseq-1.4.3.0
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             deepseq-1.4.3.0=34da2d42d10eacba0aad99c95b538637
haddock-interfaces: /usr/share/doc/haskell-dlist/html/dlist.haddock
haddock-html: /usr/share/doc/haskell-dlist/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
